Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Container ¶
type Container struct {
ID string
Host string
Port string
User string
Password string
Database string
// contains filtered or unexported fields
}
Container represents a running PostgreSQL Docker container.
func StartPostgres ¶
StartPostgres starts a PostgreSQL-compatible container with the given image. The image parameter should be a full image reference (e.g. "postgres:18", "citusdata/citus:12.1"). If the image exists locally it is used directly; otherwise it is pulled from the registry.
Click to show internal directories.
Click to hide internal directories.